@@ -109,7 +109,10 @@ class JSONRPC20Request(JSONRPCBaseRequest):
     @classmethod
     def from_json(cls, json_str):
         data = cls.deserialize(json_str)
+        return cls.from_data(data)
 
+    @classmethod
+    def from_data(cls, data):
         is_batch = isinstance(data, list)
         data = data if is_batch else [data]
 
@@ -207,7 +210,6 @@ class JSONRPC20Response(JSONRPCBaseResponse):
     def data(self, value):
         if not isinstance(value, dict):
             raise ValueError("data should be dict")
-
         self._data = value
 
     @property
@@ -216,11 +218,9 @@ class JSONRPC20Response(JSONRPCBaseResponse):
 
     @result.setter
     def result(self, value):
-        if value is not None:
-            if self.error is not None:
-                raise ValueError("Either result or error should be used")
-
-            self._data["result"] = value
+        if self.error:
+            raise ValueError("Either result or error should be used")
+        self._data["result"] = value
 
     @property
     def error(self):
@@ -228,12 +228,11 @@ class JSONRPC20Response(JSONRPCBaseResponse):
 
     @error.setter
     def error(self, value):
-        if value is not None:
-            if self.result is not None:
-                raise ValueError("Either result or error should be used")
-
-            JSONRPCError(**value)
+        self._data.pop('value', None)
+        if value:
             self._data["error"] = value
+            # Test error
+            JSONRPCError(**value)
 
     @property
     def _id(self):
